@@ -23,33 +23,36 @@ function (x, file = NULL, sep = "\t", header = TRUE)
         rm(i)
     }
     else if (isTRUE(is.na(dim(x)[3]) == TRUE) == FALSE) {
-        ts <- rep(0, dim(x)[3])
-        df <- data.frame(matrix(ncol = (dim(x)[3] + 2), nrow = 0))
+        ts <- rep(0L, dim(x)[3])
+        DF <- data.frame(matrix(ncol = (dim(x)[3] + 2L), nrow = 0L))
         for (k in 1:dim(x)[3]) {
             tmp <- transf(x[, , k], lb2lb = TRUE, labels = dimnames(x)[[1]])
             for (i in 1:length(tmp)) {
-                ts[k] <- 1
-                df[(nrow(df) + 1), ] <- c(strsplit(tmp[i], ", ")[[1]][1], 
+                ts[k] <- 1L
+                DF[(nrow(DF) + 1L), ] <- c(strsplit(tmp[i], ", ")[[1]][1], 
                   strsplit(tmp[i], ", ")[[1]][2], ts)
-                ts <- rep(0, dim(x)[3])
+                ts <- rep(0L, dim(x)[3])
             }
             rm(i)
         }
         rm(k)
         isol <- dimnames(x)[[1]][which(!(dimnames(x)[[1]] %in% 
             dimnames(rm.isol(x))[[1]]))]
-        for (i in 1:length(isol)) {
-            df[(nrow(df) + 1), ] <- c(isol[i], isol[i], ts)
+        if (isTRUE(length(isol) > 0L) == TRUE) {
+            for (i in 1:length(isol)) {
+                DF[(nrow(DF) + 1L), ] <- c(isol[i], isol[i], 
+                  ts)
+            }
+            rm(i)
         }
-        rm()
-        colnames(df) <- c("Sender", "Receiver", dimnames(x)[[3]])
+        colnames(DF) <- c("Sender", "Receiver", dimnames(x)[[3]])
         if (header) {
-            write.table(df, file = file, quote = FALSE, sep = sep, 
-                row.names = FALSE, col.names = TRUE)
+            utils::write.table(DF, file = file, quote = FALSE, 
+                sep = sep, row.names = FALSE, col.names = TRUE)
         }
         else if (!header) {
-            write.table(df, file = file, quote = FALSE, sep = sep, 
-                row.names = FALSE, col.names = FALSE)
+            utils::write.table(DF, file = file, quote = FALSE, 
+                sep = sep, row.names = FALSE, col.names = FALSE)
         }
     }
 }
